@@ -10,7 +10,7 @@ directory = path.dirname(path.realpath(__file__))
 
 @pytest.fixture(name="profile_plotter_path")
 def make_profile_plotter_setup():
-    return "{}/../../../test_files/plotting/profiles/".format(
+    return "{}/files/plots/profiles/".format(
         os.path.dirname(os.path.realpath(__file__))
     )
 
@@ -18,7 +18,7 @@ def make_profile_plotter_setup():
 @pytest.fixture(autouse=True)
 def set_config_path():
     aa.conf.instance = aa.conf.Config(
-        path.join(directory, "../test_files/plot"), path.join(directory, "output")
+        path.join(directory, "files/plotter"), path.join(directory, "output")
     )
 
 
@@ -26,7 +26,7 @@ def test__all_quantities_are_output(
     lp_0, sub_grid_7x7, positions_7x7, include_all, profile_plotter_path, plot_patch
 ):
 
-    aast.plot.lp.profile_image(
+    aast.plot.LightProfile.profile_image(
         light_profile=lp_0,
         grid=sub_grid_7x7,
         positions=positions_7x7,
